@@ -1,5 +1,3 @@
-# coding=utf-8
-from __future__ import unicode_literals
 from .. import Provider as InternetProvider
 
 
@@ -9,4 +7,4 @@ class Provider(InternetProvider):
         'gmail.com', 'daum.net', 'hotmail.com', 'hanmail.net',
         'naver.com', 'nate.com', 'live.com', 'dreamwiz.com',
     )
-    tlds = ('com', 'com', 'com', 'kr', 'kr', 'net', 'org',)
+    tlds = ('com', 'com', 'com', 'kr', 'kr', 'net', 'org')
